# Examples

The examples provided are supposed to illustrate the usage of AASM as a language.

## Facebook

The facebook simulations showcase basic functionalities of AASM, namely minimal example of sending and receiving parametrised messages.
Two versions are provided, with and without macro usage.

## Wolfsheep

A more complex simulation, showcasing computational capabilities of AASM, as well as advanced state management.
The simulation has been inspired by the [Wolf Sheep simple](http://www.netlogoweb.org/launch#http://www.netlogoweb.org/assets/modelslib/IABM%20Textbook/chapter%204/Wolf%20Sheep%20Simple%205.nlogo) 5 example from NetLogo.

## More coming soon...
